@@ -30,6 +30,11 @@ __all__ = ['Cookie', 'CookieProfile', 'SignedCookieProfile', 'SignedSerializer',
 
 _marker = object()
 
+# Module flag to handle validation of SameSite attributes
+# See the documentation for ``make_cookie`` for more information.
+SAMESITE_VALIDATION = True
+
+
 class RequestCookies(MutableMapping):
 
     _cache_key = 'webob._parsed_cookies'
@@ -240,8 +245,10 @@ def serialize_cookie_date(v):
 def serialize_samesite(v):
     v = bytes_(v)
 
-    if v.lower() not in (b"strict", b"lax"):
-        raise ValueError("SameSite must be 'Strict' or 'Lax'")
+    if SAMESITE_VALIDATION:
+        if v.lower() not in (b"strict", b"lax", b"none"):
+            raise ValueError("SameSite must be 'strict', 'lax', or 'none'")
+
     return v
 
 
@@ -287,8 +294,14 @@ class Morsel(dict):
             if self.httponly:
                 add(b'HttpOnly')
             if self.samesite:
-                add(b'SameSite=' + self.samesite)
-        return native_(b'; '.join(result), 'ascii')
+                if not self.secure and self.samesite.lower() == b"none":
+                    raise ValueError(
+                        "Incompatible cookie attributes: "
+                        "when the samesite equals 'none', then the secure must be True"
+                    )
+                add(b"SameSite=" + self.samesite)
+
+        return native_(b"; ".join(result), "ascii")
 
     __str__ = serialize
 
@@ -440,7 +453,8 @@ _c_keys.update([b'expires', b'secure', b'httponly', b'samesite'])
 
 def make_cookie(name, value, max_age=None, path='/', domain=None,
                 secure=False, httponly=False, comment=None, samesite=None):
-    """ Generate a cookie value.
+    """
+    Generate a cookie value.
 
     ``name``
       The name of the cookie.
@@ -470,8 +484,30 @@ def make_cookie(name, value, max_age=None, path='/', domain=None,
       Set a comment on the cookie. Default: ``None``
 
     ``samesite``
-      The 'SameSite' attribute of the cookie, can be either ``"Strict"``,
-      ``"Lax"``, or ``None``.
+      The 'SameSite' attribute of the cookie, can be either ``"strict"``,
+      ``"lax"``, ``"none"``, or ``None``. By default, WebOb will validate the
+      value to ensure it conforms to the allowable options in the various draft
+      RFC's that exist.
+
+      To disable this check and send headers that are experimental or introduced
+      in a future RFC, set the module flag ``SAMESITE_VALIDATION`` to a
+      false value like:
+
+      .. code::
+
+          import webob.cookies
+          webob.cookies.SAMESITE_VALIDATION = False
+
+          ck = webob.cookies.make_cookie(cookie_name, value, samesite='future')
+
+      .. danger::
+
+          This feature has known compatibility issues with various user agents,
+          and is not yet an accepted RFC. It is therefore considered
+          experimental and subject to change.
+
+          For more information please see :ref:`Experimental: SameSite Cookies
+          <samesiteexp>`
     """
 
     # We are deleting the cookie, override max_age and expires
@@ -674,8 +710,11 @@ class CookieProfile(object):
       session cookie. Default: ``False``.
 
     ``samesite``
-      The 'SameSite' attribute of the cookie, can be either ``b"Strict"``,
-      ``b"Lax"``, or ``None``.
+      The 'SameSite' attribute of the cookie, can be either ``b"strict"``,
+      ``b"lax"``, ``b"none"``, or ``None``.
+
+      For more information please see the ``samesite`` documentation in
+      :meth:`webob.cookies.make_cookie`
 
     ``path``
       The path used for the session cookie. Default: ``'/'``.
@@ -912,8 +951,8 @@ class SignedCookieProfile(CookieProfile):
       session cookie. Default: ``False``.
 
     ``samesite``
-      The 'SameSite' attribute of the cookie, can be either ``b"Strict"``,
-      ``b"Lax"``, or ``None``.
+      The 'SameSite' attribute of the cookie, can be either ``b"strict"``,
+      ``b"lax"``, ``b"none"``, or ``None``.
 
     ``path``
       The path used for the session cookie. Default: ``'/'``.
